@@ -267,9 +267,34 @@ void MainWindow::SetOpacity(QString imagefile, int opacity)
 
 }
 
+void MainWindow::savethemedone()
+{
+    themename = ThemeWin->ui->FileName->text();
+    themedir = themename;
+    themedir = themedir.remove(QChar('\"'));
+    themedir = themedir.remove(QChar(' '));
+    themedir = themedir.simplified();
+    themedir = themedir.toLower();
+    QDir file;
+    file = "/opt/usr/share/themes/" + themedir;
+
+    if (themename.isEmpty()) {
+
+        QMaemo5InformationBox::information(this, tr("You must give name for the theme."), QMaemo5InformationBox::DefaultTimeout);
+
+    } else if (file.exists()) {
+
+        QMaemo5InformationBox::information(this, tr("Folder ") + themedir + tr(" already exists!"), QMaemo5InformationBox::DefaultTimeout);
+
+    } else {
+        ThemeWin->hide();
+        saveasnew = "1";
+        runscript();
+    }
+}
+
 void MainWindow::on_pushButton_clicked()
 {
-        QString checkboxstate;
         if ( ui->checkBoxActivate->checkState() == Qt::Checked ) {
             checkboxstate = "Reboot";
         }
@@ -277,7 +302,6 @@ void MainWindow::on_pushButton_clicked()
             checkboxstate = "0";
         }
 
-        QString Icons;
         if ( ui->Icons->checkState() == Qt::Checked ) {
             Icons = "Show icons";
         }
@@ -286,169 +310,200 @@ void MainWindow::on_pushButton_clicked()
         }
 
         writeSettings();
-        QString varattu;
-        varattu = "Theme Customizer";
-        progress.setWindowModality(Qt::WindowModal);
-        progress.setWindowTitle(varattu);
-        progress.setCancelButton(0);
-        progress.show();
-        progress.setValue(2);
-        QStringList arguments;
-        arguments << ui->FontSize->currentText() << ui->Fonter->currentText() << ui->Iconset->currentText() << Icons << ui->lineEdit->text() << ui->Snap->text() << checkboxstate << fonts << f1 << f2 << f3 << f4 << ui->lineEdit_2->text() << f5 << f6 << f7 << f8 << ui->Opacity->text();
 
-//        QMaemo5InformationBox::information(this, tr("Creating backups..."), 1);
-        progress.setLabelText(tr("Creating backups..."));
-//        sleep(2);
-        progress.setValue(4);
-        progress.setValue(6);
-        progress.setValue(8);
-        QStringList systemcommand;
-        systemcommand << "createbackups";
-        QProcess *muoks1 = new QProcess(this);
-        muoks1->start("/sbin/launchcustomizer", systemcommand);
-        muoks1->waitForFinished();
-        progress.setValue(10);
+        if ( ui->saveasnew->checkState() == Qt::Checked ) {
 
-//        QMaemo5InformationBox::information(this, tr("Setting up font family..."), 1);
-        progress.setLabelText(tr("Setting up font family..."));
-//        sleep(2);
-        progress.setValue(12);
-        progress.setValue(14);
-        progress.setValue(16);
-        progress.setValue(18);
-        systemcommand.clear();
-        systemcommand << "setfontfamily" << ui->Fonter->currentText();
-        QProcess *muoks2 = new QProcess(this);
-        muoks2->start("/sbin/launchcustomizer", systemcommand);
-        muoks2->waitForFinished();
-        progress.setValue(20);
 
-//        QMaemo5InformationBox::information(this, tr("Setting up font sizes..."), 1);
-        progress.setLabelText(tr("Setting up font sizes..."));
-//        sleep(2);
-        progress.setValue(22);
-        progress.setValue(24);
-        progress.setValue(26);
-        progress.setValue(28);
-        systemcommand.clear();
-        systemcommand << "setfontsize" << ui->FontSize->currentText();
-        QProcess *muoks3 = new QProcess(this);
-        muoks3->start("/sbin/launchcustomizer", systemcommand);
-        muoks3->waitForFinished();
-        progress.setValue(30);
+                ThemeWin = new savenewtheme(this);
+                connect(ThemeWin->ui->Save, SIGNAL(clicked()), this, SLOT(savethemedone()));
+                ThemeWin->show();
 
-//        QMaemo5InformationBox::information(this, tr("Setting up font colors..."), 1);
-        progress.setLabelText(tr("Setting up font colors..."));
-//        sleep(2);
-        progress.setValue(32);
-        progress.setValue(34);
-        progress.setValue(36);
-        progress.setValue(38);
-        systemcommand.clear();
-        systemcommand << "setfontcolors" << f1 << f2 << f3 << f4 << f5 << f6 << f7 << f8;
-        QProcess *muoks4 = new QProcess(this);
-        muoks4->start("/sbin/launchcustomizer", systemcommand);
-        muoks4->waitForFinished();
-        progress.setValue(40);
+            } else {
+                saveasnew.clear();
+                runscript();
+            }
 
-//        QMaemo5InformationBox::information(this, tr("Setting up icon theme..."), 1);
-        progress.setLabelText(tr("Setting up icon theme..."));
-//        sleep(2);
-        progress.setValue(42);
-        progress.setValue(44);
-        progress.setValue(46);
-        progress.setValue(48);
-        systemcommand.clear();
-        systemcommand << "seticontheme" << ui->Iconset->currentText();
-        QProcess *muoks5 = new QProcess(this);
-        muoks5->start("/sbin/launchcustomizer", systemcommand);
-        muoks5->waitForFinished();
-        progress.setValue(50);
+}
 
- //       QMaemo5InformationBox::information(this, tr("Setting up snap-to-grid..."), 1);
-        progress.setLabelText(tr("Setting up snap-to-grid..."));
-//        sleep(2);
-        progress.setValue(52);
-        progress.setValue(54);
-        progress.setValue(56);
-        progress.setValue(58);
-        systemcommand.clear();
-        systemcommand << "setsnaptogrid" << ui->Snap->text();
-        QProcess *muoks6 = new QProcess(this);
-        muoks6->start("/sbin/launchcustomizer", systemcommand);
-        muoks6->waitForFinished();
-        progress.setValue(60);
+void MainWindow::runscript()
+{
+    QString varattu;
+    varattu = "Theme Customizer";
+    progress.setWindowModality(Qt::WindowModal);
+    progress.setWindowTitle(varattu);
+    progress.setCancelButton(0);
+    progress.show();
+    progress.setValue(1);
+    QStringList arguments;
+    arguments << ui->FontSize->currentText() << ui->Fonter->currentText() << ui->Iconset->currentText() << Icons << ui->lineEdit->text() << ui->Snap->text() << checkboxstate << fonts << f1 << f2 << f3 << f4 << ui->lineEdit_2->text() << f5 << f6 << f7 << f8 << ui->Opacity->text();
 
- //       QMaemo5InformationBox::information(this, tr("Setting up shortcut and bookmark sizes..."), 1);
-        progress.setLabelText(tr("Setting up shortcut and bookmark sizes..."));
-//        sleep(2);
-        progress.setValue(62);
-        progress.setValue(64);
-        progress.setValue(66);
-        progress.setValue(68);
-        systemcommand.clear();
-        systemcommand << "seticonsizes" << ui->lineEdit->text() << ui->lineEdit_2->text() << Icons;
-        QProcess *muoks7 = new QProcess(this);
-        muoks7->start("/sbin/launchcustomizer", systemcommand);
-        muoks7->waitForFinished();
-        progress.setValue(70);
+    if ( saveasnew == "1" ) {
 
-        int opasity = ui->Opacity->text().toInt();
-        int opasity_top = ui->Opacity_top->text().toInt();
- //       QMaemo5InformationBox::information(this, tr("Setting up widget opacities..."), 1);
-        progress.setLabelText(tr("Setting up widget opacities..."));
-        progress.setValue(72);
-        progress.setValue(74);
-        progress.setValue(76);
-        progress.setValue(78);
-        SetOpacity("ApplicationShortcutApplet.png", opasity);
-        SetOpacity("CalendarAppletBackground.png", opasity);
-        SetOpacity("ContactsAppletFrame.png", opasity);
-        SetOpacity("MapAppletButton.png", opasity);
-        SetOpacity("MapAppletHead.png", opasity);
-        SetOpacity("MediaPlayerAppletHead.png", opasity);
-        progress.setValue(80);
-        SetOpacity("MediaPlayerAppletNext.png", opasity);
-        SetOpacity("MediaPlayerAppletPrevious.png", opasity);
-        SetOpacity("MediaPlayerAppletStopPlay.png", opasity);
-        SetOpacity("OviCenter.png", opasity);
-        SetOpacity("OviLeft.png", opasity);
-        SetOpacity("OviRight.png", opasity);
-        SetOpacity("RSSAppletHead.png", opasity);
-        SetOpacity("WebShortcutAppletBackground.png", opasity);
-        SetOpacity("wmLeftButtonAttached.png", opasity_top);
-        SetOpacity("wmLeftButtonEnd.png", opasity_top);
-        SetOpacity("wmRightButton.png", opasity_top);
-	SetOpacity("wmButtonRightHalf.png", opasity_top);
-	SetOpacity("wmButtonLeftHalf.png", opasity_top);
-        progress.setValue(82);
-        progress.setValue(84);
-        progress.setValue(86);
-        progress.setValue(88);
-
-        if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
-
-            progress.setLabelText(tr("Restarting services..."));
-            QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."));
-            system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
-            system("sleep 2");
-            system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
-            system("sleep 2 && killall hildon-status-menu");
-            system("sleep 2 && killall systemui");
-            progress.setValue(99);
-            system("sleep 2 && killall hildon-desktop");
-            system("killall theme-customizer");
-
-        } else {
-
-        system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
-        system("/sbin/launchcustomizer rebootnow");
-        progress.setValue(99);
-        progress.cancel();
-        // oldfonts();
+                progress.setLabelText(tr("Saving new theme..."));
+                progress.setValue(2);
+                progress.setValue(3);
+                progress.setValue(4);
+                QStringList systemcommand;
+                systemcommand << "saveasnew" << themename << themedir;
+                QProcess *muoks0 = new QProcess(this);
+                muoks0->start("/sbin/launchcustomizer", systemcommand);
+                muoks0->waitForFinished();
+                progress.setValue(5);
 
     }
 
+//        QMaemo5InformationBox::information(this, tr("Creating backups..."), 1);
+    progress.setLabelText(tr("Creating backups..."));
+//        sleep(2);
+    progress.setValue(6);
+    progress.setValue(7);
+    progress.setValue(8);
+    QStringList systemcommand;
+    systemcommand << "createbackups";
+    QProcess *muoks1 = new QProcess(this);
+    muoks1->start("/sbin/launchcustomizer", systemcommand);
+    muoks1->waitForFinished();
+    progress.setValue(10);
+
+//        QMaemo5InformationBox::information(this, tr("Setting up font family..."), 1);
+    progress.setLabelText(tr("Setting up font family..."));
+//        sleep(2);
+    progress.setValue(12);
+    progress.setValue(14);
+    progress.setValue(16);
+    progress.setValue(18);
+    systemcommand.clear();
+    systemcommand << "setfontfamily" << ui->Fonter->currentText();
+    QProcess *muoks2 = new QProcess(this);
+    muoks2->start("/sbin/launchcustomizer", systemcommand);
+    muoks2->waitForFinished();
+    progress.setValue(20);
+
+//        QMaemo5InformationBox::information(this, tr("Setting up font sizes..."), 1);
+    progress.setLabelText(tr("Setting up font sizes..."));
+//        sleep(2);
+    progress.setValue(22);
+    progress.setValue(24);
+    progress.setValue(26);
+    progress.setValue(28);
+    systemcommand.clear();
+    systemcommand << "setfontsize" << ui->FontSize->currentText();
+    QProcess *muoks3 = new QProcess(this);
+    muoks3->start("/sbin/launchcustomizer", systemcommand);
+    muoks3->waitForFinished();
+    progress.setValue(30);
+
+//        QMaemo5InformationBox::information(this, tr("Setting up font colors..."), 1);
+    progress.setLabelText(tr("Setting up font colors..."));
+//        sleep(2);
+    progress.setValue(32);
+    progress.setValue(34);
+    progress.setValue(36);
+    progress.setValue(38);
+    systemcommand.clear();
+    systemcommand << "setfontcolors" << f1 << f2 << f3 << f4 << f5 << f6 << f7 << f8;
+    QProcess *muoks4 = new QProcess(this);
+    muoks4->start("/sbin/launchcustomizer", systemcommand);
+    muoks4->waitForFinished();
+    progress.setValue(40);
+
+//        QMaemo5InformationBox::information(this, tr("Setting up icon theme..."), 1);
+    progress.setLabelText(tr("Setting up icon theme..."));
+//        sleep(2);
+    progress.setValue(42);
+    progress.setValue(44);
+    progress.setValue(46);
+    progress.setValue(48);
+    systemcommand.clear();
+    systemcommand << "seticontheme" << ui->Iconset->currentText();
+    QProcess *muoks5 = new QProcess(this);
+    muoks5->start("/sbin/launchcustomizer", systemcommand);
+    muoks5->waitForFinished();
+    progress.setValue(50);
+
+//       QMaemo5InformationBox::information(this, tr("Setting up snap-to-grid..."), 1);
+    progress.setLabelText(tr("Setting up snap-to-grid..."));
+//        sleep(2);
+    progress.setValue(52);
+    progress.setValue(54);
+    progress.setValue(56);
+    progress.setValue(58);
+    systemcommand.clear();
+    systemcommand << "setsnaptogrid" << ui->Snap->text();
+    QProcess *muoks6 = new QProcess(this);
+    muoks6->start("/sbin/launchcustomizer", systemcommand);
+    muoks6->waitForFinished();
+    progress.setValue(60);
+
+//       QMaemo5InformationBox::information(this, tr("Setting up shortcut and bookmark sizes..."), 1);
+    progress.setLabelText(tr("Setting up shortcut and bookmark sizes..."));
+//        sleep(2);
+    progress.setValue(62);
+    progress.setValue(64);
+    progress.setValue(66);
+    progress.setValue(68);
+    systemcommand.clear();
+    systemcommand << "seticonsizes" << ui->lineEdit->text() << ui->lineEdit_2->text() << Icons;
+    QProcess *muoks7 = new QProcess(this);
+    muoks7->start("/sbin/launchcustomizer", systemcommand);
+    muoks7->waitForFinished();
+    progress.setValue(70);
+
+    int opasity = ui->Opacity->text().toInt();
+    int opasity_top = ui->Opacity_top->text().toInt();
+//       QMaemo5InformationBox::information(this, tr("Setting up widget opacities..."), 1);
+    progress.setLabelText(tr("Setting up widget opacities..."));
+    progress.setValue(72);
+    progress.setValue(74);
+    progress.setValue(76);
+    progress.setValue(78);
+    SetOpacity("ApplicationShortcutApplet.png", opasity);
+    SetOpacity("CalendarAppletBackground.png", opasity);
+    SetOpacity("ContactsAppletFrame.png", opasity);
+    SetOpacity("MapAppletButton.png", opasity);
+    SetOpacity("MapAppletHead.png", opasity);
+    SetOpacity("MediaPlayerAppletHead.png", opasity);
+    progress.setValue(80);
+    SetOpacity("MediaPlayerAppletNext.png", opasity);
+    SetOpacity("MediaPlayerAppletPrevious.png", opasity);
+    SetOpacity("MediaPlayerAppletStopPlay.png", opasity);
+    SetOpacity("OviCenter.png", opasity);
+    SetOpacity("OviLeft.png", opasity);
+    SetOpacity("OviRight.png", opasity);
+    SetOpacity("RSSAppletHead.png", opasity);
+    SetOpacity("WebShortcutAppletBackground.png", opasity);
+    SetOpacity("wmLeftButtonAttached.png", opasity_top);
+    SetOpacity("wmLeftButtonEnd.png", opasity_top);
+    SetOpacity("wmRightButton.png", opasity_top);
+    SetOpacity("wmButtonRightHalf.png", opasity_top);
+    SetOpacity("wmButtonLeftHalf.png", opasity_top);
+    progress.setValue(82);
+    progress.setValue(84);
+    progress.setValue(86);
+    progress.setValue(88);
+
+    if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
+
+        progress.setLabelText(tr("Restarting services..."));
+        QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."));
+        system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
+        system("sleep 2");
+        system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
+        system("sleep 2 && killall hildon-status-menu");
+        system("sleep 2 && killall systemui");
+        progress.setValue(99);
+        system("sleep 2 && killall hildon-desktop");
+        system("killall theme-customizer");
+
+    } else {
+
+    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
+    system("/sbin/launchcustomizer rebootnow");
+    progress.setValue(99);
+    progress.cancel();
+    // oldfonts();
+
+}
 
 }
 
@@ -657,34 +712,6 @@ void MainWindow::on_fontimport_triggered()
     connect(process2, SIGNAL(finished(int)), this, SLOT(process2Finished(int)));
     process2->start("/sbin/launchcustomizer", arguments2);
     progress2.show();
-
-/*    QMessageBox msgBox;
-    msgBox.setWindowTitle(tr("Theme Customizer - font import"));
-    msgBox.setText(tr("Do you want to import fonts from MyDocs?"));
-    msgBox.setInformativeText(tr("Note: this function will only import .ttf and .otf fonts from root of MyDocs"));
-    msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
-    msgBox.setDefaultButton(QMessageBox::Yes);
-    msgBox.button(msgBox.Yes)->setText(tr("Yes"));
-    msgBox.button(msgBox.No)->setText(tr("No"));
-    int ret = msgBox.exec();
-
-    if ( ret == QMessageBox::Yes ) {
-
-        QString varattu2;
-        varattu2 = tr("Importing fonts");
-        progress2.setWindowModality(Qt::WindowModal);
-        progress2.setWindowTitle(varattu2);
-        progress2.setCancelButton(0);
-        QStringList arguments2;
-        arguments2 << "importfontspushed";
-        QProcess *process2 = new QProcess(this);
-        connect(process2, SIGNAL(finished(int)), this, SLOT(process2Finished(int)));
-        process2->start("/sbin/launchcustomizer", arguments2);
-        progress2.show();
-
-    }
-
-*/
 }
 
 void MainWindow::process2Finished(int)
