@@ -19,6 +19,8 @@
 #include "ui_savepreset.h"
 #include "managepresets.h"
 #include "ui_managepresets.h"
+#include "savenewtheme.h"
+#include "ui_savenewtheme.h"
 #include <QtMaemo5/QMaemo5InformationBox>
 #include <QFileDialog>
 
@@ -60,9 +62,15 @@ private:
     QString f7;
     QString f8;
     QString lastpath;
+    QString saveasnew;
+    QString checkboxstate;
+    QString Icons;
+    QString themename;
+    QString themedir;
     backgrounds* newWin;
     savepreset* SaveWin;
     managepresets* ManWin;
+    savenewtheme* ThemeWin;
 
 private slots:
     void on_Opacity_top_editingFinished();
@@ -72,6 +80,8 @@ private slots:
     void delclicked();
     void on_pushButton_4_clicked();
     void savedone();
+    void savethemedone();
+    void runscript();
     void on_pushButton_3_clicked();
     void on_actionChange_backgrounds_triggered();
     void on_horizontalSlider_4_valueChanged(int value);
