@@ -13,6 +13,31 @@
         <source>Restore theme files</source>
         <translation>Återställ temafiler</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>You must give name for the theme.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Folder </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source> already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Saving new theme...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Save as new theme</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Menu bar opacity</source>
@@ -480,4 +505,17 @@
         <translation>Orginalfärger för nuvarnade tema</translation>
     </message>
 </context>
+<context>
+    <name>savenewtheme</name>
+    <message>
+        <location filename="savenewtheme.ui" line="0"/>
+        <source>Save theme as...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="savenewtheme.ui" line="0"/>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
